/* scoreops.h
 * headers for functions dealing with the whole score

 * for Denemo, a gtk+ frontend to GNU Lilypond
 * (c) 2000-2005 Matthew Hiller */
#ifndef SCOREOPS_H
#define SCOREOPS_H

#include <denemo/denemo.h>

void init_score (struct scoreinfo *si);

void free_score (struct scoreinfo *si);

/* get rid of the lily parse tree of a score and its window; hide its status bar */
void abandon_lily_tree(scoreinfo *si);
struct mudelaheaderinfo *new_mudela_header();
scoreconfig * new_score_config();

#endif
